# -*- coding: utf-8 -*-

#
# penguin_py - A lightweight, customizable stopwatch  decorator
#
# Andres Espitia
# espitiaandres.com
# espitiaandres123@gmail.com
#
# License: MIT
#


# Colours are ANSI escape sequences for the terminal to show them.


# Foreground colours are for the **text**
foreground_colours = {
    "red": "\033[91m",
    "yellow": "\033[93m",
    "green": "\033[92m",
    "blue": "\033[94m",
    "magenta": "\033[95m",
    "cyan": "\033[96m",
    "grey": "\033[37m",
}

# Background colours are for the **text's highlight**
background_colours = {
    "red": "\033[41m",
    "yellow": "\033[43m",
    "green": "\033[42m",
    "blue": "\033[44m",
    "magenta": "\033[45m",
    "cyan": "\033[46m",
    "grey": "\033[37m",
    "black": "\033[40m",
    "white": "\033[107m",
}

colour_map = {
    "foreground": foreground_colours,
    "background": background_colours,
}



# -*- coding: utf-8 -*-

#
# penguin_py - A lightweight, customizable stopwatch  decorator
#
# Andres Espitia
# espitiaandres.com
# espitiaandres123@gmail.com
#
# License: MIT
#

from .colour_map import colour_map


def get_default_colours():
    """
    Gets default colours to display in the terminal.

    These being:
    - Foreground: grey
    - Background: black
    """
    grey_foreground_colour = colour_map["foreground"]["grey"]
    black_background_colour = colour_map["background"]["black"]

    return grey_foreground_colour, black_background_colour



# -*- coding: utf-8 -*-

#
# penguin_py - A lightweight, customizable stopwatch  decorator
#
# Andres Espitia
# espitiaandres.com
# espitiaandres123@gmail.com
#
# License: MIT
#

from .get_time_msg import get_time_msg
from .processing import DataProcessing



# -*- coding: utf-8 -*-

#
# penguin_py - A lightweight, customizable stopwatch  decorator
#
# Andres Espitia
# espitiaandres.com
# espitiaandres123@gmail.com
#
# License: MIT
#

from .log_args import log_args
from .log_return import log_return



# -*- coding: utf-8 -*-

#
# penguin_py - A lightweight, customizable stopwatch  decorator
#
# Andres Espitia
# espitiaandres.com
# espitiaandres123@gmail.com
#
# License: MIT
#

from typing import Literal

from .colour_map import colour_map


def get_logger_colour(colour: str, colour_type: Literal["background", "foreground"]):
    """
    Gets the logger foreground and background colours using the colour_map dictionary in colour_map.py

    Foreground colours are for the **text**
    Background colours are for the **text's highlight**
    """
    all_possible_colours = list(colour_map[colour_type].keys())

    if colour in all_possible_colours:
        return colour_map[colour_type][colour]

    colour_dict = colour_map[colour_type]

    if colour_type == "foreground":
        return colour_dict["grey"]
    else:
        return colour_dict["black"]
